@@ -4,7 +4,7 @@ from pyg_base._as_primitive import as_primitive
 from pyg_base._cache import cache, get_cache, cache_func
 from pyg_base._cfg import mkdir, cfg_read, cfg_write, CFG
 from pyg_base._dates import iso, dt, uk2dt, us2dt, dt_bump, as_tz, tz_convert, today, ymd, TMIN, TMAX, DAY, futcodes, dt2str, is_bump, nth_weekday_of_month, mmm2m
-from pyg_base._decorators import kwargs_support, wrapper, try_value, try_back, try_nan, try_none, try_zero, try_false, try_true, try_list, timer
+from pyg_base._decorators import kwargs_support, kwpartial, wrapper, try_value, try_back, try_nan, try_none, try_zero, try_false, try_true, try_list, timer
 from pyg_base._dict import Dict, items_to_tree, tree_items, tree_keys, tree_values, tree_setitem, tree_getitem, tree_get, tree_update, dict_invert
 from pyg_base._dictattr import dictattr, relabel, getattrs
 from pyg_base._dictable import dictable, dict_concat, is_dictable
@@ -31,5 +31,6 @@ from pyg_base._types import is_pd, is_arr, is_int, is_float, is_num, is_bool, is
 from pyg_base._ulist import ulist, rng
 from pyg_base._waiter import waiter, async_wrapper
 from pyg_base._zip import zipper, lens
+from pyg_base._roll import df_roll_off
 from pyg_npy import np_save, pd_to_npy, pd_read_npy, path_name, path_dirname, path_join, mkdir
 
